pub struct Prompt { /* private fields */ }Expand description
A prompt to be used for LLM-based vector generation
This struct represents an instruction prompt that will be sent to a Large Language Model for generating vector representations based on the provided attribute description.
Fields
instruction- The formatted instruction string that will be sent to the LLM
Implementations