Module vector

Module vector 

Structs

Vector
A vector that contains a vectorized data and the original data. This struct pairs the original data with its vector representation and type information.

Enums

DataType
The type of data that is being vectorized. This enum represents the different types of data that can be processed and vectorized in the system.

Traits

VectorOperations
Shared behaviors between Vector types. This trait defines the common operations that can be performed on vectorized data regardless of the underlying data type.